sqlalchemy.ext — SQLAlchemy 0.5.6 Documentation

# SQLAlchemy 0.5.6 Documentation

Search:
Version: 0.5.6 Last Updated: 09/13/2009 10:45:11

# sqlalchemy.ext

SQLAlchemy has a variety of extensions available which provide extra functionality to SA, either via explicit usage or by augmenting the core behavior.

- declarative
  - Synopsis
  - Defining Attributes
  - Association of Metadata and Engine
  - Configuring Relations
  - Configuring Many-to-Many Relations
  - Defining Synonyms
  - Table Configuration
  - Mapper Configuration
  - Inheritance Configuration
    - Joined Table Inheritance
    - Single Table Inheritance
    - Concrete Table Inheritance
  - Class Usage
- associationproxy
  - Simplifying Relations
  - Simplifying Association Object Relations
  - Building Complex Views
  - API
- orderinglist
- serializer
- SqlSoup
  - Introduction
  - Loading objects
    - Full query documentation
  - Modifying objects
  - Joins
  - Relations
  - Advanced Use
    - Accessing the Session
    - Mapping arbitrary Selectables
    - Raw SQL
    - Dynamic table names
  - Extra tests
- compiler
  - Synopsis